# Week 4 - 스케줄링 2

MLFQ(다단계 피드백 큐) 스케줄링 알고리즘은 프로세스의 실행 특성에 따라 동적으로 우선순위를 조정합니다. 프로세스가 타임 슬라이스가 끝나기 전에 스스로 CPU를 양보하면 같은 우선순위를 유지합니다. 타임 슬라이스는 각 프로세스에 할당되는 CPU 사용 시간 단위로, 이를 모두 사용하면 선점되고 자발적으로 양보하면 우선순위가 유지됩니다. 이러한 규칙을 통해 I/O를 많이 수행하는 프로세스는 높은 우선순위를 유지하고, CPU를 오래 사용하는 프로세스는 점차 낮은 우선순위로 이동하게 됩니다.

비례 배분 스케줄링의 핵심은 각 프로세스에게 할당된 '점유율(share)'을 어떻게 구현하느냐에 있습니다. 추첨 스케줄링은 각 프로세스의 점유율을 추첨권 수로 표현하는 방식으로, 다양한 방법이 사용될 수 있습니다. 비례 배분 스케줄링은 응답 시간이나 반환 시간 같은 성능 지표와는 무관하게, 시스템 자원을 사용자나 관리자가 지정한 비율에 따라 엄격히 배분하는 데 주안점을 둡니다. 이는 기존의 스케줄링 알고리즘과는 다른 관점에서 공정성을 추구하는 접근 방식입니다.

```{tableofcontents}

```
